{{ header }}

.. _api.plotting:

========
Plotting
========
.. currentmodule:: pandas.plotting

The following functions are contained in the `pandas.plotting` module.

.. autosummary::
   :toctree: api/

   andrews_curves
   bootstrap_plot
   deregister_matplotlib_converters
   lag_plot
   parallel_coordinates
   radviz
   register_matplotlib_converters
   scatter_matrix
